@@ -304,6 +304,7 @@ class LoadResponseSet(object):
                         **i['yield_function'].get_parameters(),
                         'fit_info': (dict(i['yield_function'].fit_info)
                                      if i['yield_function'].fit_info else None),
+                        'yield_point': i['yield_function'].yield_point,
                     }
                 }
                 for i in self.fitted_yield_functions
@@ -617,7 +618,8 @@ class LoadResponseSet(object):
                                 show_axes=True, up=None, show_contour_grid=False,
                                 show_stress_states=True, join_stress_states=False,
                                 show_numerical_lankford=False,
-                                show_numerical_lankford_fit=False, layout=None):
+                                show_numerical_lankford_fit=False, layout=None,
+                                use_plotly_contour=False):
         'Visualise all fitted yield functions and data in 2D.'
 
         if not self.fitted_yield_functions:
@@ -655,6 +657,7 @@ class LoadResponseSet(object):
             show_numerical_lankford=show_numerical_lankford,
             show_numerical_lankford_fit=show_numerical_lankford_fit,
             layout=layout,
+            use_plotly_contour=use_plotly_contour,
         )
 
     def show_yield_stresses_2D(self):
